/*  Copyright (C) 2023 Tibor 'Igor2' Palinkas - license: Creative Commons CC0 */

#include <stdlib.h>
#include <stdio.h>

#include <libnoxgl.h>

#include <GL/gl.h>
#include <GLES2/gl2.h>

typedef struct {
	void *context;
	void *surface;
} my_context_t;

int main(int argc, char *argv[])
{
	noxgl_t *noxgl;
	my_context_t myctx;
	GLint gi;
	GLuint fb = 1234;
	int res;
	const char *device = "/dev/dri/card0";

	if (argc > 1)
		device = argv[1];

	printf("libnoxgl version: %d.%d.%d\n", noxgl_ver_major, noxgl_ver_minor, noxgl_ver_patch);

	noxgl = noxgl_init(device, 1);
	if (noxgl == NULL) {
		fprintf(stderr, "Failed to create noxgl context\n");
		return -1;
	}

	res = noxgl_create_context(noxgl, &myctx.context, &myctx.surface);
	if (res != 0) {
		printf("Failed to create OpenGL context\n");
		return -1;
	}

	printf("Initialization OK.\n");
	noxgl_print_info(noxgl);

	glGetIntegerv(GL_MAX_TEXTURE_SIZE, &gi);
	printf("max texture size: %d\n", gi);
	glGetIntegerv(GL_MAX_TEXTURE_IMAGE_UNITS, &gi);
	printf("max texture image units: %d\n", gi);

	printf("d1: %x == 0\n", glGetError());
	glClearColor(0.5, 0.5, 0.5, 1.0);
	printf("d2: %x == 0\n", glGetError());
	glClear(GL_COLOR_BUFFER_BIT);
	printf("d3: %x == 0\n", glGetError());

	glGenFramebuffers(1, &fb);                  /* create FBO (off-screen framebuffer) */
	printf("d4: %x == 0\n", glGetError());
	glBindFramebuffer(GL_FRAMEBUFFER_EXT, fb);  /* bind offscreen buffer */
	printf("d5: %x == 0\n", glGetError());

	printf("fb: %d != 0\n", fb);

	return 0;
}
